@@ -9,6 +9,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.gcube.portal.clientcontext.client.GCubeClientContext;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.GridHeaderColumnMenuItemEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.GridHeaderColumnMenuItemType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.CellData;
@@ -33,6 +34,7 @@ import org.gcube.portlets.user.tdwx.client.model.util.ColumnConfigGenerator;
 import org.gcube.portlets.user.tdwx.client.style.DefaultRowStyle;
 import org.gcube.portlets.user.tdwx.client.util.ColumnPositionComparator;
 import org.gcube.portlets.user.tdwx.client.util.PagingLoadUrlEncoder;
+import org.gcube.portlets.user.tdwx.shared.Constants;
 import org.gcube.portlets.user.tdwx.shared.ServletParameters;
 import org.gcube.portlets.user.tdwx.shared.StaticFilterInformation;
 import org.gcube.portlets.user.tdwx.shared.model.ColumnDefinition;
@@ -77,7 +79,6 @@ import com.sencha.gxt.widget.core.client.menu.Menu;
 import com.sencha.gxt.widget.core.client.menu.MenuItem;
 import com.sencha.gxt.widget.core.client.menu.SeparatorMenuItem;
 import com.sencha.gxt.widget.core.client.selection.CellSelection;
-import com.sencha.gxt.widget.core.client.toolbar.PagingToolBar;
 
 /**
  * 
@@ -101,12 +102,12 @@ public class TabularDataXGridPanel extends ContentPanel {
 
 	private ListStore<DataRow> store;
 	private Grid<DataRow> grid;
-	
+
 	private TableDefinition tableDefinition;
 
 	private VerticalLayoutContainer container;
 
-	//private ExtendedLiveGridView<DataRow> liveGridView;
+	// private ExtendedLiveGridView<DataRow> liveGridView;
 
 	private DataRowPagingReader reader;
 
@@ -132,7 +133,6 @@ public class TabularDataXGridPanel extends ContentPanel {
 
 	private PagingToolBarX pagingToolBar;
 
-	
 	/**
 	 * @param eventBus
 	 */
@@ -149,7 +149,7 @@ public class TabularDataXGridPanel extends ContentPanel {
 		container = new VerticalLayoutContainer();
 		container.setBorders(false);
 		add(container, new MarginData(0));
-	
+
 	}
 
 	/**
@@ -447,14 +447,14 @@ public class TabularDataXGridPanel extends ContentPanel {
 			List<ColumnConfig<DataRow, ?>> columns = columnModel.getColumns();
 
 			List<ColumnConfig<DataRow, ?>> columnsNew = new ArrayList<ColumnConfig<DataRow, ?>>();
-			
+
 			DataRowColumnConfig<?> columnTarget = null;
 			for (ColumnConfig<DataRow, ?> col : columns) {
 				columnTarget = (DataRowColumnConfig<?>) col;
 				String columnLocal = columnTarget.getDefinition()
 						.getColumnLocalId();
 				if (visibleOnlyColumn.compareTo(columnLocal) == 0) {
-					
+
 					columnTarget.setHidden(false);
 					columnsNew.add(columnTarget);
 				} else {
@@ -683,64 +683,57 @@ public class TabularDataXGridPanel extends ContentPanel {
 						.generateConfiguration(columnDefinition));
 		}
 
-
 		columnModel = new ColumnModel<DataRow>(columnsConfig);
 
 		columnModel = checkOnlyColumn(columnModel);
 
 		/*
-		columnModel
-				.addColumnMoveHandler(new ColumnMoveEvent.ColumnMoveHandler() {
-
-					@Override
-					public void onColumnMove(ColumnMoveEvent event) {
-						int columnIndex = event.getIndex();
-						@SuppressWarnings("unchecked")
-						ColumnConfig<DataRow, ?> col = (ColumnConfig<DataRow, ?>) event
-								.getColumnConfig();
-						DataRowColumnConfig<?> columnDataRow = (DataRowColumnConfig<?>) col;
-						ColumnDefinition colDef = columnDataRow.getDefinition();
-
-						Log.debug("Column Reordering", "Index: " + columnIndex
-								+ " Label: " + colDef.getLabel()
-								+ " Position: " + colDef.getPosition()
-								+ " ColumnId: " + colDef.getColumnLocalId());
-
-						if (colDef.isViewColumn()) {
-							Info.display("Attention",
-									"The view columns can not be moved");
-							// ColumnHeader<DataRow>
-							// colHeader=grid.getView().getHeader();
-
-							// event.getSource().moveColumn(columnIndex,
-							// colDef.getPosition());
-						} else {
-							ColumnsReorderingConfig columnsReorderingConfig = new ColumnsReorderingConfig(
-									columnIndex, colDef);
-							ColumnsReorderingEvent columnsReorderingEvent = new ColumnsReorderingEvent(
-									columnsReorderingConfig);
-							eventBus.fireEvent(columnsReorderingEvent);
-						}
-					}
-				});
-		*/
+		 * columnModel .addColumnMoveHandler(new
+		 * ColumnMoveEvent.ColumnMoveHandler() {
+		 * 
+		 * @Override public void onColumnMove(ColumnMoveEvent event) { int
+		 * columnIndex = event.getIndex();
+		 * 
+		 * @SuppressWarnings("unchecked") ColumnConfig<DataRow, ?> col =
+		 * (ColumnConfig<DataRow, ?>) event .getColumnConfig();
+		 * DataRowColumnConfig<?> columnDataRow = (DataRowColumnConfig<?>) col;
+		 * ColumnDefinition colDef = columnDataRow.getDefinition();
+		 * 
+		 * Log.debug("Column Reordering", "Index: " + columnIndex + " Label: " +
+		 * colDef.getLabel() + " Position: " + colDef.getPosition() +
+		 * " ColumnId: " + colDef.getColumnLocalId());
+		 * 
+		 * if (colDef.isViewColumn()) { Info.display("Attention",
+		 * "The view columns can not be moved"); // ColumnHeader<DataRow> //
+		 * colHeader=grid.getView().getHeader();
+		 * 
+		 * // event.getSource().moveColumn(columnIndex, //
+		 * colDef.getPosition()); } else { ColumnsReorderingConfig
+		 * columnsReorderingConfig = new ColumnsReorderingConfig( columnIndex,
+		 * colDef); ColumnsReorderingEvent columnsReorderingEvent = new
+		 * ColumnsReorderingEvent( columnsReorderingConfig);
+		 * eventBus.fireEvent(columnsReorderingEvent); } } });
+		 */
 		if (grid == null) {
 			Log.debug("Setup reader");
 
 			reader = new DataRowPagingReader(tableDefinition);
 
-			String path = GWT.getModuleBaseURL() + "tdwxdata";
+			String path = GWT.getModuleBaseURL()
+					+ Constants.TABULAR_DATA_X_SERVLET + "?"
+					+ Constants.CURR_GROUP_ID + "="
+					+ GCubeClientContext.getCurrentContextId();
 			RequestBuilder builder = new RequestBuilder(RequestBuilder.POST,
 					path);
 			builder.setHeader(ServletParameters.TD_SESSION_ID,
 					String.valueOf(tdSessionId));
-			
+			builder.setHeader(Constants.CURR_GROUP_ID,
+					GCubeClientContext.getCurrentContextId());
 
 			HttpProxy<FilterPagingLoadConfig> proxy = new HttpProxy<FilterPagingLoadConfig>(
 					builder);
 			proxy.setWriter(new PagingLoadUrlEncoder(staticFilters));
 
-
 			loader = new PagingLoader<FilterPagingLoadConfig, PagingLoadResult<DataRow>>(
 					proxy, reader) {
 				@Override
@@ -756,12 +749,11 @@ public class TabularDataXGridPanel extends ContentPanel {
 
 			pagingToolBar = new PagingToolBarX(PAGINGDIMENSION);
 			pagingToolBar.getElement().getStyle()
-					.setProperty("borderBottom", "none");			
+					.setProperty("borderBottom", "none");
 			pagingToolBar.fixPageTextWidth();
 			pagingToolBar.setItemId("TDMPagingToolBarX");
 			pagingToolBar.bind(loader);
 
-
 			grid = new Grid<DataRow>(store, columnModel) {
 				@Override
 				protected void onAfterFirstAttach() {
@@ -779,7 +771,7 @@ public class TabularDataXGridPanel extends ContentPanel {
 			grid.setSelectionModel(sm);
 			grid.setLoadMask(true);
 			grid.setLoader(loader);
-			
+
 			grid.setBorders(false);
 			grid.setColumnReordering(false);
 
@@ -799,7 +791,6 @@ public class TabularDataXGridPanel extends ContentPanel {
 			container.add(grid, new VerticalLayoutData(1, 1, new Margins(0)));
 			container.add(pagingToolBar, new VerticalLayoutData(1, -1));
 
-			
 			if (contextMenu != null) {
 				grid.setContextMenu(contextMenu);
 			} else
@@ -811,7 +802,7 @@ public class TabularDataXGridPanel extends ContentPanel {
 
 		} else {
 			Log.debug("Setup grid not null");
-			
+
 			reader.setDefinition(tableDefinition);
 			loader.clearSortInfo();
 
@@ -819,20 +810,18 @@ public class TabularDataXGridPanel extends ContentPanel {
 					store));
 
 			grid.reconfigure(store, columnModel);
-			
 
 			// Filter
 			ArrayList<Filter<DataRow, ?>> filters = FiltersGenerator
 					.generate(columnModel);
 
-			
 			Log.debug("Filters: " + filters.size());
 			for (Filter<DataRow, ?> filterGeneric : filters) {
 				gridFilters.addFilter(filterGeneric);
 			}
 
 			loader.load();
-			
+
 		}
 
 		if (tableViewConfig != null) {
@@ -852,7 +841,7 @@ public class TabularDataXGridPanel extends ContentPanel {
 			grid.getView().setViewConfig(
 					new TabularDataGridViewConfig(tableViewConfig,
 							tableDefinition));
-			
+
 		}
 
 		container.forceLayout();
